# Reference

<!-- DO NOT EDIT: This document was generated by Puppet Strings -->

## Table of Contents

### Classes

- [`secrets`](#secrets): Manage secrets on a given host

### Defined types

- [`secrets::load`](#secretsload): This type will provide the actual file requested

## Classes

### <a name="secrets"></a>`secrets`

This class will fetch secrets from the puppet server
that follow a specific layout.

#### Examples

#####

```puppet
class {'secrets':
  install => { '/etc/krb5.keytab' => {
                    'owner' => 'root',
                    'group' => 'root',
                    'mode'  => '0400',
                    'mandatory'  => 'true',
                    'secretbase' => '/my/secrets/repo/on/server',
                    'posix_acl'  => { 'action'     => 'set',
                                    'permission' => ['group:wheel:r--', ],},
                    'selrange'   => 's0',
                    'seluser'    => 'system_u',
                    'selrole'    => 'object_r',
                    'seltype'    => 'krb5_keytab_t',  },
             }
}
```

#### Parameters

The following parameters are available in the `secrets` class:

- [`install`](#install)
- [`defaults`](#defaults)

##### <a name="install"></a>`install`

Data type: `Hash`

Secrets to install on the system

##### <a name="defaults"></a>`defaults`

Data type: `Hash`

Passed as a list of defaults to the installed secrets

## Defined types

### <a name="secretsload"></a>`secrets::load`

Find the secret on the system and make the relevant Files

#### Examples

#####

```puppet
secrets::load { '/etc/krb5.keytab':
  owner => 'root',
  group => 'root',
  mode  => '0400',
  mandatory  => 'true',
  secretbase => '/my/secrets/repo/on/server',
  posix_acl  => { 'action'     => 'set',
                  'permission' => ['group:wheel:r--', ],},
  selrange   => 's0',
  seluser    => 'system_u',
  selrole    => 'object_r',
  seltype    => 'krb5_keytab_t',
}
```

#### Parameters

The following parameters are available in the `secrets::load` defined type:

- [`mandatory`](#mandatory)
- [`notify_services`](#notify_services)
- [`posix_acl`](#posix_acl)
- [`secretbase`](#secretbase)
- [`path`](#path)
- [`owner`](#owner)
- [`group`](#group)
- [`mode`](#mode)
- [`selinux_ignore_defaults`](#selinux_ignore_defaults)
- [`selrange`](#selrange)
- [`seluser`](#seluser)
- [`selrole`](#selrole)
- [`seltype`](#seltype)

##### <a name="mandatory"></a>`mandatory`

Data type: `Boolean`

Should the catalog crash if this secret doesn't exist

Default value: `true`

##### <a name="notify_services"></a>`notify_services`

Data type: `Array`

Service **titles** to try and notify if this changes.

Default value: `[]`

##### <a name="posix_acl"></a>`posix_acl`

Data type: `Hash`

Set these posix acls (see posix_acl resource)

Default value: `{}`

##### <a name="secretbase"></a>`secretbase`

Data type: `Stdlib::Absolutepath`

The directory to use as the base to start the secret search

Default value: `'/etc/puppetlabs/secrets/'`

##### <a name="path"></a>`path`

Data type: `Stdlib::Absolutepath`

Passed directly to the `file` resource

Default value: `$title`

##### <a name="owner"></a>`owner`

Data type: `Variant[String,Integer]`

Passed directly to the `file` resource

Default value: `'root'`

##### <a name="group"></a>`group`

Data type: `Variant[String,Integer]`

Passed directly to the `file` resource

Default value: `'root'`

##### <a name="mode"></a>`mode`

Data type: `String`

Passed directly to the `file` resource

Default value: `'0400'`

##### <a name="selinux_ignore_defaults"></a>`selinux_ignore_defaults`

Data type: `Boolean`

Passed directly to the `file` resource

Default value: `false`

##### <a name="selrange"></a>`selrange`

Data type: `Optional[String]`

Passed directly to the `file` resource

Default value: `undef`

##### <a name="seluser"></a>`seluser`

Data type: `Optional[String]`

Passed directly to the `file` resource

Default value: `undef`

##### <a name="selrole"></a>`selrole`

Data type: `Optional[String]`

Passed directly to the `file` resource

Default value: `undef`

##### <a name="seltype"></a>`seltype`

Data type: `Optional[String]`

Passed directly to the `file` resource

Default value: `undef`
